@@ -12,12 +12,14 @@ from mgz.header.achievements import achievements
 from mgz.header.scenario import scenario
 from mgz.header.lobby import lobby
 from mgz.header.de import de
+from mgz.header.hd import hd
 
 
 compressed_header = Struct(
     "game_version"/CString(encoding='latin1'),
     "save_version"/VersionAdapter(Float32l),
     "version"/Computed(lambda ctx: get_version(ctx.game_version, ctx.save_version, None)),
+    "hd"/If(lambda ctx: ctx.version == Version.HD and ctx.save_version > 12.34, hd),
     "de"/If(lambda ctx: ctx.version == Version.DE, de),
     ai,
     replay,
@@ -29,6 +31,7 @@ compressed_header = Struct(
     Terminated
 )
 
+
 subheader = Struct(
     "check"/Peek(Int32ul),
     "chapter_address"/If(lambda ctx: ctx.check < 100000000, Int32ul),
